@@ -71,7 +71,7 @@ async fn test_get_object() -> Result<()> {
         .expect("request must succeed");
 
     let status = resp.status();
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     debug!("got response content: {}", resp.text().await?);
     assert_eq!(StatusCode::NOT_FOUND, status);
     Ok(())
@@ -99,7 +99,7 @@ async fn test_delete_objects() -> Result<()> {
  </Delete>"#;
     let mut req = Request::new(content);
     *req.method_mut() = http::Method::POST;
-    *req.uri_mut() = http::Uri::from_str(&format!("{}/?delete", url))?;
+    *req.uri_mut() = http::Uri::from_str(&format!("{url}/?delete"))?;
     req.headers_mut()
         .insert(CONTENT_LENGTH, content.len().to_string().parse().unwrap());
     req.headers_mut()
@@ -109,7 +109,7 @@ async fn test_delete_objects() -> Result<()> {
         .sign(&mut req, &cred)
         .expect("sign request must success");
 
-    debug!("signed request: {:?}", req);
+    debug!("signed request: {req:?}");
 
     let client = Client::new();
     let resp = client
@@ -118,7 +118,7 @@ async fn test_delete_objects() -> Result<()> {
         .expect("request must succeed");
 
     let status = resp.status();
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     debug!("got response content: {}", resp.text().await?);
     assert_eq!(StatusCode::OK, status);
     Ok(())
@@ -144,7 +144,7 @@ async fn test_get_object_with_query_sign() -> Result<()> {
         .sign_query(&mut req, Duration::from_secs(3600), &cred)
         .expect("sign request must success");
 
-    debug!("signed request: {:?}", req);
+    debug!("signed request: {req:?}");
 
     let client = Client::new();
     let resp = client
@@ -153,7 +153,7 @@ async fn test_get_object_with_query_sign() -> Result<()> {
         .expect("request must succeed");
 
     let status = resp.status();
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     debug!("got response content: {}", resp.text().await?);
     assert_eq!(StatusCode::NOT_FOUND, status);
     Ok(())
@@ -183,7 +183,7 @@ async fn test_head_object_with_special_characters() -> Result<()> {
         .sign(&mut req, &cred)
         .expect("sign request must success");
 
-    debug!("signed request: {:?}", req);
+    debug!("signed request: {req:?}");
 
     let client = Client::new();
     let resp = client
@@ -191,7 +191,7 @@ async fn test_head_object_with_special_characters() -> Result<()> {
         .await
         .expect("request must success");
 
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     assert_eq!(StatusCode::NOT_FOUND, resp.status());
     Ok(())
 }
@@ -222,7 +222,7 @@ async fn test_put_object_with_special_characters() -> Result<()> {
         .sign(&mut req, &cred)
         .expect("sign request must success");
 
-    debug!("signed request: {:?}", req);
+    debug!("signed request: {req:?}");
 
     let client = Client::new();
     let resp = client
@@ -231,7 +231,7 @@ async fn test_put_object_with_special_characters() -> Result<()> {
         .expect("request must success");
 
     let status = resp.status();
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     debug!("got response content: {:?}", resp.text().await?);
     assert_eq!(StatusCode::OK, status);
     Ok(())
@@ -258,7 +258,7 @@ async fn test_list_bucket() -> Result<()> {
         .sign(&mut req, &cred)
         .expect("sign request must success");
 
-    debug!("signed request: {:?}", req);
+    debug!("signed request: {req:?}");
 
     let client = Client::new();
     let resp = client
@@ -267,7 +267,7 @@ async fn test_list_bucket() -> Result<()> {
         .expect("request must success");
 
     let status = resp.status();
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     debug!("got response content: {}", resp.text().await?);
     assert_eq!(StatusCode::OK, status);
     Ok(())
@@ -293,7 +293,7 @@ async fn test_list_bucket_with_upper_cases() -> Result<()> {
         .sign(&mut req, &cred)
         .expect("sign request must success");
 
-    debug!("signed request: {:?}", req);
+    debug!("signed request: {req:?}");
 
     let client = Client::new();
     let resp = client
@@ -302,7 +302,7 @@ async fn test_list_bucket_with_upper_cases() -> Result<()> {
         .expect("request must success");
 
     let status = resp.status();
-    debug!("got response: {:?}", resp);
+    debug!("got response: {resp:?}");
     debug!("got response content: {}", resp.text().await?);
     assert_eq!(StatusCode::OK, status);
     Ok(())
